@@ -23,7 +23,32 @@ shinyUI(
                                 # ,tags$script(src="AFM.js")
                               )
                             )),
-                   tabPanel('PSD',
+             tabPanel('Gaussian Mixtures',
+                      sidebarLayout(
+                        sidebarPanel(
+                          uiOutput('imageNameGaussianMix'),
+                          tags$hr(),
+                          numericInput("mepsilonGaussianMix", "Convergence criterion:", 1e-4, min = 1e-20, max = 1e-2),
+                          sliderInput("minmaxGaussianMix", label = h5("Number of components"), min = 2, max = 8, step = 1,
+                                      value = c(2, 3)),
+                          tags$hr(),
+                          actionButton('calculateGaussianMixButton',label='Calculate')
+                        )
+                        ,
+                        mainPanel(
+     
+                            tabPanel("Plot",
+                                     fluidRow(
+                                       uiOutput('plotGaussianMixUI'),
+                                       plotOutput("plotGaussianMixPlot"),
+                                       uiOutput('summaryGaussianMixUI'),
+                                       verbatimTextOutput("gaussianMixSummary"))
+                            )
+                          
+                        )
+                      )),
+             navbarMenu('PSD',
+                            tabPanel('Calculation',
                             sidebarLayout(
                               sidebarPanel(
                                 uiOutput('imageNamePSD'),
@@ -38,11 +63,33 @@ shinyUI(
                               ,
                               mainPanel(
                                 uiOutput('plotPSDUI'),
-                                plotOutput('plotPSD'),
+                                plotOutput('plotPSD')
+                                ,
                                 uiOutput('plotPSDRvsLUI'),
                                 plotOutput('plotPSDRvsL')
                               )
                             )),
+                            tabPanel('Analysis',
+                                     sidebarLayout(
+                                       sidebarPanel(
+                                         uiOutput('imageNameAnalysisPSD'),
+                                         tags$hr(),
+                                         sliderInput('firstSlopeSliderPSD', label = 'First tangent',
+                                                     min = 1, max = 124, value = c(1,32), step=1, ticks=FALSE),
+                                         
+                                         sliderInput('lcSliderPSD', label = 'Lc tangent',
+                                                     min = 1, max = 124, value = c(10,70), step=1, ticks=FALSE),
+                                         actionButton('RoughnessByLengthScaleAnalysisButton', label = 'Calculate'),
+                                         tags$hr(),
+                                         uiOutput('downloadRoughnessVsLengthscaleAnalysisPSDButton')
+                                       )
+                                       ,
+                                       mainPanel(
+                                         uiOutput('plotAnalysisPSDRvsLUI'),
+                                         plotOutput('plotAnalysisPSDRvsL')
+                                       )
+                                     )
+                            )),
                    
                    navbarMenu('Variance',
                               tabPanel('Checks',
@@ -158,7 +205,7 @@ shinyUI(
                             mainPanel(
                               tags$iframe(
                                 seamless="seamless",
-                                src="http://www.openbmap.com/AFM/index_afmapp.html",style="width: 400px; height: 400px")
+                                src="http://www.afmist.org/index_afmapp.html",style="width: 400px; height: 400px")
                             )
                    ),
              tags$head(tags$script(src="google-analytics.js")),
